@@ -18,44 +18,46 @@ ModelAnalyticInfusion = setClass(
     odeSolverParameters = list(NULL)))
 
 
-setMethod(
-  f="initialize",
-  signature="ModelAnalyticInfusion",
-  definition= function (.Object, name, description, equations, outcomes, parameters, modelError)
-  {
-    if(!missing(name))
-    {
-      .Object@name = name
-    }
-    if(!missing(description))
-    {
-      .Object@description = description
-    }
-    if(!missing(equations))
-    {
-      .Object@equations = equations
-    }
-    if(!missing(outcomes))
-    {
-      .Object@outcomes = outcomes
-    }
-    if(!missing(parameters))
-    {
-      .Object@parameters = parameters
-    }
-    if(!missing(modelError))
-    {
-      .Object@modelError = modelError
-    }
-    validObject(.Object)
-    return (.Object )
-  }
+setMethod( f="initialize",
+           signature="ModelAnalyticInfusion",
+           definition= function (.Object, name, description, equations, outcomes, parameters, modelError)
+           {
+             if(!missing(name))
+             {
+               .Object@name = name
+             }
+             if(!missing(description))
+             {
+               .Object@description = description
+             }
+             if(!missing(equations))
+             {
+               .Object@equations = equations
+             }
+             if(!missing(outcomes))
+             {
+               .Object@outcomes = outcomes
+             }
+             if(!missing(parameters))
+             {
+               .Object@parameters = parameters
+             }
+             if(!missing(modelError))
+             {
+               .Object@modelError = modelError
+             }
+             validObject(.Object)
+             return (.Object )
+           }
 )
 
 # ======================================================================================================
 # EvaluateModel
 # ======================================================================================================
 
+#' @rdname EvaluateModel
+#' @export
+
 setMethod(f="EvaluateModel",
           signature =  "ModelAnalyticInfusion",
           definition=function( object, arm )
@@ -587,6 +589,9 @@ setMethod(f="EvaluateModel",
 # definePKModel
 # ======================================================================================================
 
+#' @rdname definePKModel
+#' @export
+
 setMethod("definePKModel",
           signature( "ModelAnalyticInfusion"),
           function( object, outcomes )
@@ -806,6 +811,9 @@ setMethod("definePKModel",
 # definePKPDModel
 # ======================================================================================================
 
+#' @rdname definePKPDModel
+#' @export
+
 setMethod("definePKPDModel",
           signature( "ModelAnalyticInfusion", "ModelAnalytic" ),
           function( PKModel, PDModel, outcomes )
@@ -1036,6 +1044,9 @@ setMethod("definePKPDModel",
 # definePKPDModel
 # ======================================================================================================
 
+#' @rdname definePKPDModel
+#' @export
+
 setMethod("definePKPDModel",
           signature( "ModelAnalyticInfusion", "ModelODE" ),
           function( PKModel, PDModel, outcomes )
@@ -1307,6 +1318,9 @@ setMethod("definePKPDModel",
 # convertPKModelAnalyticToPKModelODE
 # ======================================================================================================
 
+#' @rdname convertPKModelAnalyticToPKModelODE
+#' @export
+
 setMethod("convertPKModelAnalyticToPKModelODE",
           signature("ModelAnalyticInfusion"),
           function( object )
