@@ -19,43 +19,45 @@ ModelError = setClass(Class = "ModelError",
                         cError = "numeric"
                       ))
 
-setMethod(
-  f="initialize",
-  signature="ModelError",
-  definition= function (.Object, outcome, equation, derivatives, sigmaInter, sigmaSlope, cError  )
-  {
-    if(!missing(outcome))
-    {
-      .Object@outcome = outcome
-    }
-    if(!missing(equation))
-    {
-      .Object@equation = equation
-    }
-    if(!missing(derivatives))
-    {
-      .Object@derivatives = derivatives
-    }
-    if(!missing(sigmaInter))
-    {
-      .Object@sigmaInter = sigmaInter
-    }
-    if(!missing(sigmaSlope))
-    {
-      .Object@sigmaSlope = sigmaSlope
-    }
-    if( !missing( cError ) )
-    {
-      .Object@cError = cError
-    }
-    validObject(.Object)
-    return (.Object )
-  })
+setMethod( f="initialize",
+           signature="ModelError",
+           definition= function (.Object, outcome, equation, derivatives, sigmaInter, sigmaSlope, cError  )
+           {
+             if(!missing(outcome))
+             {
+               .Object@outcome = outcome
+             }
+             if(!missing(equation))
+             {
+               .Object@equation = equation
+             }
+             if(!missing(derivatives))
+             {
+               .Object@derivatives = derivatives
+             }
+             if(!missing(sigmaInter))
+             {
+               .Object@sigmaInter = sigmaInter
+             }
+             if(!missing(sigmaSlope))
+             {
+               .Object@sigmaSlope = sigmaSlope
+             }
+             if( !missing( cError ) )
+             {
+               .Object@cError = cError
+             }
+             validObject(.Object)
+             return (.Object )
+           })
 
 # ======================================================================================================
 # getOutcome
 # ======================================================================================================
 
+#' @rdname getOutcome
+#' @export
+
 setMethod("getOutcome",
           "ModelError",
           function( object )
@@ -63,13 +65,12 @@ setMethod("getOutcome",
             return( object@outcome )
           })
 
-# ======================================================================================================
 #' Get the equation of a model error.
 #'
 #' @name getEquation
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @return An expression giving the equation of a model error.
-# ======================================================================================================
+#' @export
 
 setGeneric("getEquation",
            function(object)
@@ -77,6 +78,9 @@ setGeneric("getEquation",
              standardGeneric("getEquation")
            })
 
+#' @rdname getEquation
+#' @export
+
 setMethod("getEquation",
           "ModelError",
           function( object )
@@ -84,15 +88,13 @@ setMethod("getEquation",
             return( object@equation )
           })
 
-
-# ======================================================================================================
 #' Set the equation of a model error.
 #'
 #' @name setEquation
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @param equation An expression giving the equation of a model error.
 #' @return The model error with the updated equation.
-# ======================================================================================================
+#' @export
 
 setGeneric("setEquation",
            function( object, equation )
@@ -100,6 +102,9 @@ setGeneric("setEquation",
              standardGeneric("setEquation")
            })
 
+#' @rdname setEquation
+#' @export
+
 setMethod("setEquation",
           "ModelError",
           function( object, equation )
@@ -109,13 +114,12 @@ setMethod("setEquation",
             return( object )
           })
 
-# ======================================================================================================
 #' Get the derivatives of the model error equation.
 #'
 #' @name getDerivatives
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @return The derivatives of the model error equation.
-# ======================================================================================================
+#' @export
 
 setGeneric("getDerivatives",
            function(object)
@@ -123,6 +127,9 @@ setGeneric("getDerivatives",
              standardGeneric("getDerivatives")
            })
 
+#' @rdname getDerivatives
+#' @export
+
 setMethod("getDerivatives",
           "ModelError",
           function( object )
@@ -130,14 +137,13 @@ setMethod("getDerivatives",
             return( object@derivatives )
           })
 
-# ======================================================================================================
 #' Set the derivatives of the model error equation.
 #'
 #' @name setDerivatives
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @param derivatives The derivatives of the model error equation.
 #' @return The model error with the updated model error equation.
-# ======================================================================================================
+#' @export
 
 setGeneric("setDerivatives",
            function( object, derivatives )
@@ -145,6 +151,9 @@ setGeneric("setDerivatives",
              standardGeneric("setDerivatives")
            })
 
+#' @rdname setDerivatives
+#' @export
+
 setMethod("setDerivatives",
           "ModelError",
           function( object, derivatives )
@@ -154,13 +163,12 @@ setMethod("setDerivatives",
             return( object )
           })
 
-# ======================================================================================================
 #' Get the parameter sigma inter.
 #'
 #' @name getSigmaInter
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @return A numeric giving the parameter sigma inter.
-# ======================================================================================================
+#' @export
 
 setGeneric("getSigmaInter",
            function( object )
@@ -168,6 +176,9 @@ setGeneric("getSigmaInter",
              standardGeneric("getSigmaInter")
            })
 
+#' @rdname getSigmaInter
+#' @export
+
 setMethod("getSigmaInter",
           "ModelError",
           function( object )
@@ -175,14 +186,13 @@ setMethod("getSigmaInter",
             return( object@sigmaInter )
           })
 
-# ======================================================================================================
 #' Set the parameter sigma inter.
 #'
 #' @name setSigmaInter
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @param sigmaInter A numeric giving the parameter sigma inter.
 #' @return The model error with the updated sigma inter.
-# ======================================================================================================
+#' @export
 
 setGeneric("setSigmaInter",
            function( object, sigmaInter )
@@ -190,6 +200,9 @@ setGeneric("setSigmaInter",
              standardGeneric("setSigmaInter")
            })
 
+#' @rdname setSigmaInter
+#' @export
+
 setMethod("setSigmaInter",
           "ModelError",
           function( object, sigmaInter)
@@ -199,13 +212,12 @@ setMethod("setSigmaInter",
             return( object )
           })
 
-# ======================================================================================================
 #' Get the parameter sigma slope.
 #'
 #' @name getSigmaSlope
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @return A numeric giving the parameter sigma slope.
-# ======================================================================================================
+#' @export
 
 setGeneric("getSigmaSlope",
            function( object )
@@ -213,6 +225,9 @@ setGeneric("getSigmaSlope",
              standardGeneric("getSigmaSlope")
            })
 
+#' @rdname getSigmaSlope
+#' @export
+
 setMethod("getSigmaSlope",
           "ModelError",
           function( object )
@@ -220,14 +235,13 @@ setMethod("getSigmaSlope",
             return( object@sigmaSlope )
           })
 
-# ======================================================================================================
 #' Set the parameter sigma slope.
 #'
 #' @name setSigmaSlope
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @param sigmaSlope A numeric giving the parameter sigma slope.
 #' @return The model error with the updated sigma slope.
-# ======================================================================================================
+#' @export
 
 setGeneric("setSigmaSlope",
            function( object, sigmaSlope )
@@ -235,6 +249,9 @@ setGeneric("setSigmaSlope",
              standardGeneric("setSigmaSlope")
            })
 
+#' @rdname setSigmaSlope
+#' @export
+
 setMethod("setSigmaSlope",
           "ModelError",
           function( object, sigmaSlope)
@@ -244,13 +261,12 @@ setMethod("setSigmaSlope",
             return( object )
           })
 
-# ======================================================================================================
 #' Get the parameter c.
 #'
 #' @name getcError
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @return A numeric giving the parameter c.
-# ======================================================================================================
+#' @export
 
 setGeneric("getcError",
            function( object )
@@ -258,6 +274,9 @@ setGeneric("getcError",
              standardGeneric("getcError")
            })
 
+#' @rdname getcError
+#' @export
+
 setMethod("getcError",
           "ModelError",
           function( object )
@@ -265,14 +284,13 @@ setMethod("getcError",
             return( object@cError )
           })
 
-# ======================================================================================================
 #' Set the parameter c.
 #'
 #' @name setcError
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @param cError A numeric giving the parameter c.
 #' @return The model error with the parameter c.
-# ======================================================================================================
+#' @export
 
 setGeneric("setcError",
            function( object, cError )
@@ -280,6 +298,9 @@ setGeneric("setcError",
              standardGeneric("setcError")
            })
 
+#' @rdname setcError
+#' @export
+
 setMethod("setcError",
           "ModelError",
           function( object, cError)
@@ -293,6 +314,9 @@ setMethod("setcError",
 # getParameters
 # ======================================================================================================
 
+#' @rdname getParameters
+#' @export
+
 setMethod("getParameters",
           "ModelError",
           function(object) {
@@ -307,14 +331,13 @@ setMethod("getParameters",
             return(parameters)
           })
 
-# ======================================================================================================
 #' Evaluate the error model derivatives.
 #'
 #' @name EvaluateErrorModelDerivatives
 #' @param object An object from the class \linkS4class{ModelError}.
 #' @param evaluationOutcome A list giving the results of the model evaluation.
 #' @return A list giving the error variance and the Sigma derivatives.
-# ======================================================================================================
+#' @export
 
 setGeneric("EvaluateErrorModelDerivatives",
            function( object, evaluationOutcome )
@@ -322,6 +345,9 @@ setGeneric("EvaluateErrorModelDerivatives",
              standardGeneric("EvaluateErrorModelDerivatives")
            })
 
+#' @rdname EvaluateErrorModelDerivatives
+#' @export
+
 setMethod(f="EvaluateErrorModelDerivatives",
           signature = "ModelError",
           definition = function( object, evaluationOutcome )
